Version history
===============

This library adheres to `Semantic Versioning 2.0 <http://semver.org/>`_.

**1.1.0**

- Added the ``start_server()`` method to all web components

**1.0.0**

- Initial release
